pymanifesto package
===================

Submodules
----------

pymanifesto.pymanifesto module
------------------------------

.. automodule:: pymanifesto.pymanifesto
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pymanifesto
    :members:
    :undoc-members:
    :show-inheritance:
